# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'uis/MarkersROIs.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MarkersROIs(object):
    def setupUi(self, MarkersROIs):
        MarkersROIs.setObjectName("MarkersROIs")
        MarkersROIs.resize(457, 770)
        self.verticalLayout = QtWidgets.QVBoxLayout(MarkersROIs)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_2 = QtWidgets.QGroupBox(MarkersROIs)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.but_add_marker = QtWidgets.QPushButton(self.groupBox_2)
        self.but_add_marker.setObjectName("but_add_marker")
        self.horizontalLayout.addWidget(self.but_add_marker)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.layout_markers = QtWidgets.QWidget(self.groupBox_2)
        self.layout_markers.setMinimumSize(QtCore.QSize(0, 0))
        self.layout_markers.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.layout_markers.setObjectName("layout_markers")
        self.verticalLayout_2.addWidget(self.layout_markers)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.verticalLayout.addWidget(self.groupBox_2)
        self.groupBox_3 = QtWidgets.QGroupBox(MarkersROIs)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem2)
        self.but_add_roi = QtWidgets.QPushButton(self.groupBox_3)
        self.but_add_roi.setObjectName("but_add_roi")
        self.horizontalLayout_14.addWidget(self.but_add_roi)
        self.verticalLayout_8.addLayout(self.horizontalLayout_14)
        self.tb_rois = QtWidgets.QTabWidget(self.groupBox_3)
        self.tb_rois.setObjectName("tb_rois")
        self.verticalLayout_8.addWidget(self.tb_rois)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem3)
        self.verticalLayout.addWidget(self.groupBox_3)
        self.gb_sardana = QtWidgets.QGroupBox(MarkersROIs)
        self.gb_sardana.setObjectName("gb_sardana")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.gb_sardana)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.lb_screen_status_3 = QtWidgets.QLabel(self.gb_sardana)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.lb_screen_status_3.setFont(font)
        self.lb_screen_status_3.setObjectName("lb_screen_status_3")
        self.horizontalLayout_3.addWidget(self.lb_screen_status_3)
        self.cmb_roi_as_counter = QtWidgets.QComboBox(self.gb_sardana)
        self.cmb_roi_as_counter.setObjectName("cmb_roi_as_counter")
        self.horizontalLayout_3.addWidget(self.cmb_roi_as_counter)
        self.lb_screen_status_2 = QtWidgets.QLabel(self.gb_sardana)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.lb_screen_status_2.setFont(font)
        self.lb_screen_status_2.setObjectName("lb_screen_status_2")
        self.horizontalLayout_3.addWidget(self.lb_screen_status_2)
        self.cb_counter = QtWidgets.QComboBox(self.gb_sardana)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_counter.sizePolicy().hasHeightForWidth())
        self.cb_counter.setSizePolicy(sizePolicy)
        self.cb_counter.setMinimumSize(QtCore.QSize(0, 0))
        self.cb_counter.setObjectName("cb_counter")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.cb_counter.addItem("")
        self.horizontalLayout_3.addWidget(self.cb_counter)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem4)
        self.verticalLayout.addWidget(self.gb_sardana)
        spacerItem5 = QtWidgets.QSpacerItem(436, 224, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem5)

        self.retranslateUi(MarkersROIs)
        QtCore.QMetaObject.connectSlotsByName(MarkersROIs)

    def retranslateUi(self, MarkersROIs):
        _translate = QtCore.QCoreApplication.translate
        MarkersROIs.setWindowTitle(_translate("MarkersROIs", "Markers/ROIs"))
        self.groupBox_2.setTitle(_translate("MarkersROIs", "Markers"))
        self.but_add_marker.setText(_translate("MarkersROIs", "Add Marker"))
        self.groupBox_3.setTitle(_translate("MarkersROIs", "ROIs"))
        self.but_add_roi.setText(_translate("MarkersROIs", "Add ROI"))
        self.gb_sardana.setTitle(_translate("MarkersROIs", "Sardana \"counter\" behavior"))
        self.lb_screen_status_3.setText(_translate("MarkersROIs", "Source ROI:"))
        self.lb_screen_status_2.setText(_translate("MarkersROIs", "Statistics value as counter:"))
        self.cb_counter.setItemText(0, _translate("MarkersROIs", "sum"))
        self.cb_counter.setItemText(1, _translate("MarkersROIs", "max_i"))
        self.cb_counter.setItemText(2, _translate("MarkersROIs", "max_x"))
        self.cb_counter.setItemText(3, _translate("MarkersROIs", "max_y"))
        self.cb_counter.setItemText(4, _translate("MarkersROIs", "com_x"))
        self.cb_counter.setItemText(5, _translate("MarkersROIs", "com_y"))
        self.cb_counter.setItemText(6, _translate("MarkersROIs", "fwhm_x"))
        self.cb_counter.setItemText(7, _translate("MarkersROIs", "fwhm_y"))

