# Created by matveyev at 13.11.2020
from pyqtgraph import ImageView

# ----------------------------------------------------------------------
class ImageViewNoKeyboard(ImageView):
    """
    """
    def keyPressEvent(self, ev):
        pass